Documentation
¶
Overview ¶
Package markdown provides a simple Markdown-to-HTML renderer as a templ component.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApplyOutsideTags ¶
ApplyOutsideTags applies fn only to text segments outside HTML tags, so that formatting regexes never touch URLs inside href attributes, etc.
func FormatInline ¶
FormatInline applies inline formatting (bold, italic, links, images) to s.
func RenderMarkdown ¶
RenderMarkdown writes the HTML representation of md to buf.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.